==> hekate:hqed-m6_8.tar.gz: hqed/C/te/sh/HBInfoPanel.cpp <==
/*
 *     $Id: HBInfoPanel.cpp,v 1.1 2009-07-25 13:11:39 kinio Exp $
 *     
 *     Implementation by Krzysztof Wesołowski and Krzysztof Kaczor <kinio4444@gmail.com>
 *
 *     Copyright (C) 2006-9 by the HeKatE Project
 *
 *     HQEd has been develped within the HeKatE Project,
 *     see http://hekate.ia.agh.edu.pl
 *
 *     This file is part of HQEd.
 *
 *     HQEd is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     HQEd is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with HQEd.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
// -----------------------------------------------------------------------------

#include <QtGui/QFontDialog>
#include <QtGui/QPalette>
#include <QtGui/QColorDialog>

#include "HBFormatPanel.h"
#include "HBInfoPanel.h"
// -----------------------------------------------------------------------------

// #brief Constructor of this panel. Setups edited block and UI it also connects all edits with appropriate slots
//
// #param parent QWidget's parent
// #param _block block pointing to edited block
// #return no values return
HBInfoPanel::HBInfoPanel(QWidget * parent, HighlightBlock * _block)
{
     block = _block;
     this->setTitle("Basic Info");
     mainLayout=new QVBoxLayout(this);

     descriptionEdit=new QTextEdit(block->getDescription(),this);
     descriptionLabel=new QLabel("Block description:");
     mainLayout->addWidget(descriptionLabel);
     mainLayout->addWidget(descriptionEdit);

     connect(descriptionEdit,SIGNAL(textChanged()),this,SLOT(descriptionChanged()));
}
// -----------------------------------------------------------------------------

// #brief updating description in real time
//
// #return no values return
void HBInfoPanel::descriptionChanged(void)
{
     block->setDescription(descriptionEdit->toPlainText());
}
// -----------------------------------------------------------------------------

==> hekate:hqed-m6_10.tar.gz: hqed/C/te/sh/HBInfoPanel.cpp <==
/*
 *     $Id: HBInfoPanel.cpp,v 1.2 2009-10-01 08:39:52 kinio Exp $
 *     
 *     Implementation by Krzysztof Wesołowski and Krzysztof Kaczor <kinio4444@gmail.com>
 *
 *     Copyright (C) 2006-9 by the HeKatE Project
 *
 *     HQEd has been develped within the HeKatE Project,
 *     see http://hekate.ia.agh.edu.pl
 *
 *     This file is part of HQEd.
 *
 *     HQEd is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     HQEd is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with HQEd.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
// -----------------------------------------------------------------------------

#include <QtGui/QFontDialog>
#include <QtGui/QPalette>
#include <QtGui/QColorDialog>

#include "HBFormatPanel.h"
#include "HBInfoPanel.h"
// -----------------------------------------------------------------------------

// #brief Constructor of this panel. Setups edited block and UI it also connects all edits with appropriate slots
//
// #param parent QWidget's parent
// #param _block block pointing to edited block
// #return no values return
HBInfoPanel::HBInfoPanel(QWidget* /*parent*/, HighlightBlock* _block)
{
     block = _block;
     this->setTitle("Basic Info");
     mainLayout=new QVBoxLayout(this);

     descriptionEdit=new QTextEdit(block->getDescription(),this);
     descriptionLabel=new QLabel("Block description:");
     mainLayout->addWidget(descriptionLabel);
     mainLayout->addWidget(descriptionEdit);

     connect(descriptionEdit,SIGNAL(textChanged()),this,SLOT(descriptionChanged()));
}
// -----------------------------------------------------------------------------

// #brief updating description in real time
//
// #return no values return
void HBInfoPanel::descriptionChanged(void)
{
     block->setDescription(descriptionEdit->toPlainText());
}
// -----------------------------------------------------------------------------
